/*[
 * GOCAD Software.
 *
 * Copyright (c) 2008 Earth Decision Sciences
 * All rights reserved.
 *
 * The software and information contained herein are proprietary to, and
 * comprise valuable trade secrets of, Earth Decision Sciences, which
 * intends to preserve as trade secrets such software and information.
 * This software is furnished pursuant to a written license agreement and
 * may be used, copied, transmitted, and stored only in accordance with
 * the terms of such license and with the inclusion of the above copyright
 * notice. This software and information or any other copies thereof may
 * not be provided or otherwise made available to any other person.
]*/

#ifndef Gocad_appli_statistics_gs_continuous_object_h
#define Gocad_appli_statistics_gs_continuous_object_h

#include <Gocad/appli/enter_scope.h>
#include <Gocad/appli/statistics/gs_statistic_object.h>
#include <Gocad/appli/statistics/statistic_object_topology.h>

/*****************************************************************************/

namespace Gocad {
    class GSStatisticObject;
}

namespace Gocad {

class _Gocad_appli_decl GSContinuousBinnedObject {
    GOCAD_DECLARE_RTTI( GSContinuousBinnedObject );
public:
    typedef BinStatisticObjectTopoDesc::BinCount BinCount;
    typedef BinStatisticObjectTopoDesc::BinCount BinIndex;

    virtual ~GSContinuousBinnedObject();

    int serie_nb_bins() const;
    void set_serie_nb_bins( BinCount nb );
    float serie_x_min() const;
    void set_serie_x_min( float min );
    float serie_x_max() const;
    void set_serie_x_max( float max );
    CopyCString serie_x_scale() const;
    void set_serie_x_scale( const CString& x_scale );

protected:
    GSContinuousBinnedObject();

    const GSStatisticObject* binned_object() const;
    GSStatisticObject* binned_object();

    void copy_binning_data(
        const GSContinuousBinnedObject& binned_object
    );
};

/****************************************************************************/

class _Gocad_appli_decl GSStatisticObjectDiscreteModelDescriptor :
    public GSStatisticObjectModelDescriptor
{
    GOCAD_DECLARE_RTTI( GSStatisticObjectDiscreteModelDescriptor );
public:
    typedef int Index;

    GSStatisticObjectDiscreteModelDescriptor();
    virtual ~GSStatisticObjectDiscreteModelDescriptor();

    void set_index( Index index );
    Index index() const;
    void set_scale_type( const CString& scale_type );
    const CString& scale_type() const;

    virtual bool is_equal(
        const GSStatisticObject::DescriptorBase& other
    ) const;

    virtual GSStatisticObject::DescriptorBase* clone() const;
    virtual Format base_name() const;

protected:
    virtual void copy_data( GSStatisticObjectModelDescriptor& to ) const;

private:
    Index index_;
    CopyCString scale_type_;
};

/****************************************************************************/

} // namespace Gocad

#endif
